TRXASprefitpack package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 2

   TRXASprefitpack.mathfun
   TRXASprefitpack.res
   TRXASprefitpack.driver

Module contents
---------------

.. automodule:: TRXASprefitpack
   :members:
   :undoc-members:
   :show-inheritance:
